from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DepositType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DEPOSIT_TYPE_UNSPECIFIED: _ClassVar[DepositType]
    DEPOSIT_TYPE_SAVINGS: _ClassVar[DepositType]
    DEPOSIT_TYPE_CHECKING: _ClassVar[DepositType]

class PaymentAuthorizationStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PAYMENT_AUTHORIZATION_STATUS_UNSPECIFIED: _ClassVar[PaymentAuthorizationStatus]
    PAYMENT_AUTHORIZATION_STATUS_AUTHORIZED: _ClassVar[PaymentAuthorizationStatus]
    PAYMENT_AUTHORIZATION_STATUS_NOT_AUTHORIZED: _ClassVar[PaymentAuthorizationStatus]

class KycStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    KYC_STATUS_UNSPECIFIED: _ClassVar[KycStatus]
    KYC_STATUS_APPROVED: _ClassVar[KycStatus]
    KYC_STATUS_NOT_SUBMITTED: _ClassVar[KycStatus]
    KYC_STATUS_IN_REVIEW: _ClassVar[KycStatus]
    KYC_STATUS_DENIED: _ClassVar[KycStatus]

class ContractStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONTRACT_STATUS_UNSPECIFIED: _ClassVar[ContractStatus]
    CONTRACT_STATUS_INITIAL: _ClassVar[ContractStatus]
    CONTRACT_STATUS_APPROVED: _ClassVar[ContractStatus]
    CONTRACT_STATUS_ACTIVATED: _ClassVar[ContractStatus]
    CONTRACT_STATUS_WAITING_EKYC: _ClassVar[ContractStatus]
    CONTRACT_STATUS_EXPIRED: _ClassVar[ContractStatus]
    CONTRACT_STATUS_DEACTIVATED: _ClassVar[ContractStatus]
    CONTRACT_STATUS_CANCELLED: _ClassVar[ContractStatus]
    CONTRACT_STATUS_PENDING_CHARGE: _ClassVar[ContractStatus]

DEPOSIT_TYPE_UNSPECIFIED: DepositType
DEPOSIT_TYPE_SAVINGS: DepositType
DEPOSIT_TYPE_CHECKING: DepositType
PAYMENT_AUTHORIZATION_STATUS_UNSPECIFIED: PaymentAuthorizationStatus
PAYMENT_AUTHORIZATION_STATUS_AUTHORIZED: PaymentAuthorizationStatus
PAYMENT_AUTHORIZATION_STATUS_NOT_AUTHORIZED: PaymentAuthorizationStatus
KYC_STATUS_UNSPECIFIED: KycStatus
KYC_STATUS_APPROVED: KycStatus
KYC_STATUS_NOT_SUBMITTED: KycStatus
KYC_STATUS_IN_REVIEW: KycStatus
KYC_STATUS_DENIED: KycStatus
CONTRACT_STATUS_UNSPECIFIED: ContractStatus
CONTRACT_STATUS_INITIAL: ContractStatus
CONTRACT_STATUS_APPROVED: ContractStatus
CONTRACT_STATUS_ACTIVATED: ContractStatus
CONTRACT_STATUS_WAITING_EKYC: ContractStatus
CONTRACT_STATUS_EXPIRED: ContractStatus
CONTRACT_STATUS_DEACTIVATED: ContractStatus
CONTRACT_STATUS_CANCELLED: ContractStatus
CONTRACT_STATUS_PENDING_CHARGE: ContractStatus

class Buyer(_message.Message):
    __slots__ = (
        "email",
        "force_kyc",
        "phone",
        "name",
        "katakana_last_name",
        "katakana_first_name",
        "address",
        "birth_date",
        "gender",
        "expires_at",
        "metadata",
    )

    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FORCE_KYC_FIELD_NUMBER: _ClassVar[int]
    PHONE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    KATAKANA_LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    KATAKANA_FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BIRTH_DATE_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    email: str
    force_kyc: bool
    phone: str
    name: str
    katakana_last_name: str
    katakana_first_name: str
    address: str
    birth_date: str
    gender: str
    expires_at: _timestamp_pb2.Timestamp
    metadata: _containers.ScalarMap[str, str]
    def __init__(
        self,
        email: _Optional[str] = ...,
        force_kyc: bool = ...,
        phone: _Optional[str] = ...,
        name: _Optional[str] = ...,
        katakana_last_name: _Optional[str] = ...,
        katakana_first_name: _Optional[str] = ...,
        address: _Optional[str] = ...,
        birth_date: _Optional[str] = ...,
        gender: _Optional[str] = ...,
        expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        metadata: _Optional[_Mapping[str, str]] = ...,
    ) -> None: ...

class MerchantCustomer(_message.Message):
    __slots__ = ("customer", "merchant")
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    MERCHANT_FIELD_NUMBER: _ClassVar[int]
    customer: Customer
    merchant: Merchant
    def __init__(
        self,
        customer: _Optional[_Union[Customer, _Mapping]] = ...,
        merchant: _Optional[_Union[Merchant, _Mapping]] = ...,
    ) -> None: ...

class Customer(_message.Message):
    __slots__ = (
        "id",
        "email",
        "activated",
        "status",
        "bank_information",
        "created_at",
        "updated_at",
    )
    ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ACTIVATED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BANK_INFORMATION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    email: str
    activated: bool
    status: Status
    bank_information: BankInformation
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(
        self,
        id: _Optional[str] = ...,
        email: _Optional[str] = ...,
        activated: bool = ...,
        status: _Optional[_Union[Status, _Mapping]] = ...,
        bank_information: _Optional[_Union[BankInformation, _Mapping]] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class Status(_message.Message):
    __slots__ = ("payment", "kyc")
    PAYMENT_FIELD_NUMBER: _ClassVar[int]
    KYC_FIELD_NUMBER: _ClassVar[int]
    payment: PaymentAuthorizationStatus
    kyc: KycStatus
    def __init__(
        self,
        payment: _Optional[_Union[PaymentAuthorizationStatus, str]] = ...,
        kyc: _Optional[_Union[KycStatus, str]] = ...,
    ) -> None: ...

class BankInformation(_message.Message):
    __slots__ = ("account_number", "bank_name", "branch_name", "deposit_type")
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BANK_NAME_FIELD_NUMBER: _ClassVar[int]
    BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_TYPE_FIELD_NUMBER: _ClassVar[int]
    account_number: str
    bank_name: str
    branch_name: str
    deposit_type: DepositType
    def __init__(
        self,
        account_number: _Optional[str] = ...,
        bank_name: _Optional[str] = ...,
        branch_name: _Optional[str] = ...,
        deposit_type: _Optional[_Union[DepositType, str]] = ...,
    ) -> None: ...

class Merchant(_message.Message):
    __slots__ = ("id", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    def __init__(
        self, id: _Optional[str] = ..., name: _Optional[str] = ...
    ) -> None: ...

class Contract(_message.Message):
    __slots__ = ("id", "status", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: ContractStatus
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(
        self,
        id: _Optional[str] = ...,
        status: _Optional[_Union[ContractStatus, str]] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class Pagination(_message.Message):
    __slots__ = ("page_size", "page_token")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    def __init__(
        self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ...
    ) -> None: ...

class Bank(_message.Message):
    __slots__ = (
        "code",
        "name",
        "name_katakana",
        "name_hiragana",
        "name_alphabet",
        "assets",
        "quota",
        "opening_hours",
        "bankpay_scheduled_maintenances",
        "bank_scheduled_maintenances",
        "registration_scheduled_maintenances",
        "bankpay_available",
        "bank_available",
        "registration_available",
        "operating",
    )
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAME_KATAKANA_FIELD_NUMBER: _ClassVar[int]
    NAME_HIRAGANA_FIELD_NUMBER: _ClassVar[int]
    NAME_ALPHABET_FIELD_NUMBER: _ClassVar[int]
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    OPENING_HOURS_FIELD_NUMBER: _ClassVar[int]
    BANKPAY_SCHEDULED_MAINTENANCES_FIELD_NUMBER: _ClassVar[int]
    BANK_SCHEDULED_MAINTENANCES_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_SCHEDULED_MAINTENANCES_FIELD_NUMBER: _ClassVar[int]
    BANKPAY_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    BANK_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    OPERATING_FIELD_NUMBER: _ClassVar[int]
    code: str
    name: str
    name_katakana: str
    name_hiragana: str
    name_alphabet: str
    assets: BankAssets
    quota: BankQuota
    opening_hours: str
    bankpay_scheduled_maintenances: _containers.RepeatedCompositeFieldContainer[
        BankScheduledMaintenancePeriod
    ]
    bank_scheduled_maintenances: _containers.RepeatedCompositeFieldContainer[
        BankScheduledMaintenancePeriod
    ]
    registration_scheduled_maintenances: _containers.RepeatedCompositeFieldContainer[
        BankScheduledMaintenancePeriod
    ]
    bankpay_available: bool
    bank_available: bool
    registration_available: bool
    operating: bool
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        name_katakana: _Optional[str] = ...,
        name_hiragana: _Optional[str] = ...,
        name_alphabet: _Optional[str] = ...,
        assets: _Optional[_Union[BankAssets, _Mapping]] = ...,
        quota: _Optional[_Union[BankQuota, _Mapping]] = ...,
        opening_hours: _Optional[str] = ...,
        bankpay_scheduled_maintenances: _Optional[
            _Iterable[_Union[BankScheduledMaintenancePeriod, _Mapping]]
        ] = ...,
        bank_scheduled_maintenances: _Optional[
            _Iterable[_Union[BankScheduledMaintenancePeriod, _Mapping]]
        ] = ...,
        registration_scheduled_maintenances: _Optional[
            _Iterable[_Union[BankScheduledMaintenancePeriod, _Mapping]]
        ] = ...,
        bankpay_available: bool = ...,
        bank_available: bool = ...,
        registration_available: bool = ...,
        operating: bool = ...,
    ) -> None: ...

class BankQuota(_message.Message):
    __slots__ = (
        "offline_purchase_limit_per_charge_with_kyc",
        "offline_purchase_limit_per_charge_without_kyc",
        "offline_purchase_limit_per_day_with_kyc",
        "offline_purchase_limit_per_day_without_kyc",
        "subscription_purchase_limit_per_charge_with_kyc",
        "subscription_purchase_limit_per_charge_without_kyc",
        "subscription_purchase_limit_per_day_with_kyc",
        "subscription_purchase_limit_per_day_without_kyc",
    )
    OFFLINE_PURCHASE_LIMIT_PER_CHARGE_WITH_KYC_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_PURCHASE_LIMIT_PER_CHARGE_WITHOUT_KYC_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_PURCHASE_LIMIT_PER_DAY_WITH_KYC_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_PURCHASE_LIMIT_PER_DAY_WITHOUT_KYC_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_PURCHASE_LIMIT_PER_CHARGE_WITH_KYC_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_PURCHASE_LIMIT_PER_CHARGE_WITHOUT_KYC_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_PURCHASE_LIMIT_PER_DAY_WITH_KYC_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_PURCHASE_LIMIT_PER_DAY_WITHOUT_KYC_FIELD_NUMBER: _ClassVar[int]
    offline_purchase_limit_per_charge_with_kyc: int
    offline_purchase_limit_per_charge_without_kyc: int
    offline_purchase_limit_per_day_with_kyc: int
    offline_purchase_limit_per_day_without_kyc: int
    subscription_purchase_limit_per_charge_with_kyc: int
    subscription_purchase_limit_per_charge_without_kyc: int
    subscription_purchase_limit_per_day_with_kyc: int
    subscription_purchase_limit_per_day_without_kyc: int
    def __init__(
        self,
        offline_purchase_limit_per_charge_with_kyc: _Optional[int] = ...,
        offline_purchase_limit_per_charge_without_kyc: _Optional[int] = ...,
        offline_purchase_limit_per_day_with_kyc: _Optional[int] = ...,
        offline_purchase_limit_per_day_without_kyc: _Optional[int] = ...,
        subscription_purchase_limit_per_charge_with_kyc: _Optional[int] = ...,
        subscription_purchase_limit_per_charge_without_kyc: _Optional[int] = ...,
        subscription_purchase_limit_per_day_with_kyc: _Optional[int] = ...,
        subscription_purchase_limit_per_day_without_kyc: _Optional[int] = ...,
    ) -> None: ...

class BankScheduledMaintenancePeriod(_message.Message):
    __slots__ = (
        "bank_code",
        "start_at_jst",
        "end_at_jst",
        "start_at_utc",
        "end_at_utc",
    )
    BANK_CODE_FIELD_NUMBER: _ClassVar[int]
    START_AT_JST_FIELD_NUMBER: _ClassVar[int]
    END_AT_JST_FIELD_NUMBER: _ClassVar[int]
    START_AT_UTC_FIELD_NUMBER: _ClassVar[int]
    END_AT_UTC_FIELD_NUMBER: _ClassVar[int]
    bank_code: str
    start_at_jst: str
    end_at_jst: str
    start_at_utc: str
    end_at_utc: str
    def __init__(
        self,
        bank_code: _Optional[str] = ...,
        start_at_jst: _Optional[str] = ...,
        end_at_jst: _Optional[str] = ...,
        start_at_utc: _Optional[str] = ...,
        end_at_utc: _Optional[str] = ...,
    ) -> None: ...

class BankBranch(_message.Message):
    __slots__ = (
        "bank_code",
        "branch_code",
        "name",
        "name_katakana",
        "name_hiragana",
        "name_alphabet",
    )
    BANK_CODE_FIELD_NUMBER: _ClassVar[int]
    BRANCH_CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAME_KATAKANA_FIELD_NUMBER: _ClassVar[int]
    NAME_HIRAGANA_FIELD_NUMBER: _ClassVar[int]
    NAME_ALPHABET_FIELD_NUMBER: _ClassVar[int]
    bank_code: str
    branch_code: str
    name: str
    name_katakana: str
    name_hiragana: str
    name_alphabet: str
    def __init__(
        self,
        bank_code: _Optional[str] = ...,
        branch_code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        name_katakana: _Optional[str] = ...,
        name_hiragana: _Optional[str] = ...,
        name_alphabet: _Optional[str] = ...,
    ) -> None: ...

class BankAssets(_message.Message):
    __slots__ = ("bank_code", "logo_url_large", "logo_url_medium", "terms_url")
    BANK_CODE_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_LARGE_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_MEDIUM_FIELD_NUMBER: _ClassVar[int]
    TERMS_URL_FIELD_NUMBER: _ClassVar[int]
    bank_code: str
    logo_url_large: str
    logo_url_medium: str
    terms_url: str
    def __init__(
        self,
        bank_code: _Optional[str] = ...,
        logo_url_large: _Optional[str] = ...,
        logo_url_medium: _Optional[str] = ...,
        terms_url: _Optional[str] = ...,
    ) -> None: ...



from typing import Dict, Any, Optional
from .api.payment_api import PaymentApi
from .api.client import ApiClient
from .errors import ApiError


class Payment:
    """High-level payment operations"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api = PaymentApi(api_client)

    def on_session(
        self,
        customer_id: Optional[str] = None,
        price: Optional[int] = None,
        description: Optional[str] = None,
        expires_at: Optional[str] = None,
        redirect_urls: Optional[Dict[str, str]] = None,
        buyer: Optional[Dict[str, Any]] = None,
        **kwargs
    ) -> Dict[str, Any]:
        """
        Process an on-session payment (customer present)

        Args:
            customer_id: Customer ID (optional)
            price: Payment amount (optional)
            description: Description of the charge
            expires_at: ISO-8601 format expiration date (e.g. "2025-06-01T00:00:00Z")
            redirect_urls: Dict containing success_url and failure_url
            buyer: Customer information (email, phone, name, etc.)
            **kwargs: Additional parameters

        Returns:
            Payment result

        Raises:
            ApiError: If payment processing fails
        """
        try:
            # Build the base request
            request_body = {}

            # Add customer ID if provided
            if customer_id is not None:
                request_body["customer"] = customer_id

            # Create charge object only if price is provided
            if price is not None:
                charge = {"price": price}
                if description:
                    charge["description"] = description

                # Add expires_at to charge object if provided
                if expires_at:
                    charge["expires_at"] = expires_at

                request_body["charge"] = charge

            # Handle buyer information
            buyer_dict = buyer or {}  # Use provided buyer or create empty dict

            # If no charge object (no price) and expires_at is provided, add expires_at to buyer
            if price is None and expires_at is not None:
                buyer_dict["expires_at"] = expires_at

            # Add buyer to request if it's not empty
            if buyer_dict:
                request_body["buyer"] = buyer_dict

            # Add redirect URLs if provided
            if redirect_urls:
                request_body["redirect"] = redirect_urls

            # Add any additional parameters
            for key, value in kwargs.items():
                if key not in request_body:
                    request_body[key] = value

            return self.api.on_session_payment(request_body)
        except Exception as e:
            raise ApiError.from_error(e)

    def off_session(
        self,
        customer_id: str,
        price: int,
        description: Optional[str] = None,
        expires_at: Optional[str] = None,
        **kwargs
    ) -> Dict[str, Any]:
        """
        Process an off-session payment (customer not present)

        Args:
            customer_id: Customer ID
            price: Charge amount
            description: Description of the charge
            expires_at: ISO-8601 format expiration date (e.g. "2025-06-01T00:00:00Z")
            **kwargs: Additional parameters for the charge object

        Returns:
            Payment result

        Raises:
            ApiError: If payment processing fails
        """
        try:
            # Create charge object
            charge = {"price": price}

            # Add optional parameters to charge object
            if description:
                charge["description"] = description

            if expires_at:
                charge["expires_at"] = expires_at

            # Add any additional kwargs to the charge object
            for key, value in kwargs.items():
                if key not in ["customer"]:  # Exclude parameters that go at the top level
                    charge[key] = value

            # Build the complete request body
            request_body = {"customer": customer_id, "charge": charge}

            return self.api.off_session_payment(request_body)
        except Exception as e:
            raise ApiError.from_error(e)

    def _get_auth_headers(self):
        """Debug method to check what authorization headers are being used"""
        if (
            hasattr(self.api, "api_client")
            and self.api.api_client
            and hasattr(self.api.api_client, "config")
        ):
            config = self.api.api_client.config
            if hasattr(config, "auth_settings") and "oauth2" in config.auth_settings:
                auth_setting = config.auth_settings["oauth2"]
                if callable(auth_setting.get("value")):
                    header_value = auth_setting["value"]()
                    return {auth_setting["key"]: header_value}
        return None



"""Common models for Jamm SDK."""

from lib.proto.api.v1.common_pb2 import (
    Buyer as _Buyer,
    Customer as _Customer,
    MerchantCustomer as _MerchantCustomer,
    Contract as _Contract,
    Pagination as _Pagination,
    Status as _Status,
    BankInformation as _BankInformation,
    Merchant as _Merchant,
    # Enums
    DepositType as _DepositType,
    PaymentAuthorizationStatus as _PaymentAuthorizationStatus,
    KycStatus as _KycStatus,
    ContractStatus as _ContractStatus,
)


# Monkey-patch the Buyer class with additional methods
def get_metadata(self, key: str, default: str = None) -> str:
    """Get a metadata value."""
    return self.metadata.get(key, default)


def set_metadata(self, key: str, value: str) -> None:
    """Set a metadata value."""
    self.metadata[key] = value


# Add methods to the protobuf class
_Buyer.get_metadata = get_metadata
_Buyer.set_metadata = set_metadata

# Re-export as Buyer
Buyer = _Buyer

# Direct re-exports
Customer = _Customer
MerchantCustomer = _MerchantCustomer
Contract = _Contract
Pagination = _Pagination
Status = _Status
BankInformation = _BankInformation
Merchant = _Merchant

# Enum re-exports
DepositType = _DepositType
PaymentAuthorizationStatus = _PaymentAuthorizationStatus
KycStatus = _KycStatus
ContractStatus = _ContractStatus



from typing import Dict, Any, Optional
from .api.customer_api import CustomerApi
from .api.client import ApiClient
from .errors import ApiError


class Customer:
    """High-level customer operations"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api = CustomerApi(api_client)

    @property
    def KycStatus(self):
        """Access to KYC status enums"""
        try:
            from .models import KycStatus

            return KycStatus
        except ImportError:

            class MockKycStatus:
                APPROVED = "APPROVED"
                DENIED = "DENIED"
                IN_REVIEW = "IN_REVIEW"
                NOT_SUBMITTED = "NOT_SUBMITTED"

            return MockKycStatus

    @property
    def PaymentAuthorizationStatus(self):
        """Access to payment authorization status enums"""
        try:
            from .models import PaymentAuthorizationStatus

            return PaymentAuthorizationStatus
        except ImportError:

            class MockPaymentAuthorizationStatus:
                AUTHORIZED = "AUTHORIZED"
                NOT_AUTHORIZED = "NOT_AUTHORIZED"

            return MockPaymentAuthorizationStatus

    def create(self, buyer: Dict[str, Any]) -> Dict[str, Any]:
        """
        Create a customer

        Args:
            buyer: Customer data

        Returns:
            Customer object

        Raises:
            ApiError: If API call fails
        """
        try:
            request_body = {"buyer": buyer}
            r = self.api.create(request_body)

            if isinstance(r, dict) and "customer" in r:
                return r["customer"]
            else:
                return r
        except Exception as e:
            raise ApiError.from_error(e)

    def get(self, id_or_email: str) -> Dict[str, Any]:
        """
        Get a customer by ID or email

        Args:
            id_or_email: Customer ID or email

        Returns:
            Customer object with activated flag properly set

        Raises:
            ApiError: If customer not found or API error occurs
        """
        try:
            r = self.api.get(id_or_email)

            if isinstance(r, dict) and "customer" in r:
                customer = r["customer"]
            else:
                customer = r

            if customer.get("activated") is None:
                customer["activated"] = False

            return customer
        except Exception as e:
            raise ApiError.from_error(e)

    def get_contract(self, customer_id: str) -> Optional[Dict[str, Any]]:
        """
        Get customer contract

        Args:
            customer_id: Customer ID

        Returns:
            Contract data or None if not found
        """
        try:
            return self.api.get_contract(customer_id)
        except Exception as e:
            if hasattr(e, "status") and e.status == 404:
                return None
            elif hasattr(e, "code") and e.code == 404:
                return None
            elif "404" in str(e) or "not found" in str(e).lower():
                return None
            else:
                raise ApiError.from_error(e)

    def update(self, customer_id: str, data: Dict[str, Any]) -> Dict[str, Any]:
        """
        Update a customer

        Args:
            customer_id: Customer ID
            data: Update data

        Returns:
            Updated customer object

        Raises:
            ApiError: If customer not found or API error occurs
        """
        try:
            r = self.api.update(customer_id, data)

            if isinstance(r, dict) and "customer" in r:
                return r["customer"]
            else:
                return r
        except Exception as e:
            raise ApiError.from_error(e)

    def delete(self, customer_id: str) -> Dict[str, Any]:
        """
        Delete a customer

        Args:
            customer_id: Customer ID

        Returns:
            Deletion response

        Raises:
            ApiError: If customer not found or API error occurs
        """
        try:
            response = self.api.delete(customer_id)
            return response.get("accepted", False)
        except Exception as e:
            raise ApiError.from_error(e)

    def _get_auth_headers(self):
        """Debug method to check what authorization headers are being used"""
        if (
            hasattr(self.api, "api_client")
            and self.api.api_client
            and hasattr(self.api.api_client, "config")
        ):
            config = self.api.api_client.config
            if hasattr(config, "auth_settings") and "oauth2" in config.auth_settings:
                auth_setting = config.auth_settings["oauth2"]
                if callable(auth_setting.get("value")):
                    header_value = auth_setting["value"]()
                    return {auth_setting["key"]: header_value}
        return None


class CustomerClass:
    """Class-level access to Customer functionality and enums"""

    @property
    def KycStatus(self):
        try:
            from .models import KycStatus

            return KycStatus
        except ImportError:

            class MockKycStatus:
                APPROVED = "APPROVED"
                DENIED = "DENIED"
                IN_REVIEW = "IN_REVIEW"
                NOT_SUBMITTED = "NOT_SUBMITTED"

            return MockKycStatus

    @property
    def PaymentAuthorizationStatus(self):
        try:
            from .models import PaymentAuthorizationStatus

            return PaymentAuthorizationStatus
        except ImportError:

            class MockPaymentAuthorizationStatus:
                AUTHORIZED = "AUTHORIZED"
                NOT_AUTHORIZED = "NOT_AUTHORIZED"

            return MockPaymentAuthorizationStatus


Customer.KycStatus = CustomerClass().KycStatus
Customer.PaymentAuthorizationStatus = CustomerClass().PaymentAuthorizationStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/customer.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/customer.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from api.v1 import common_pb2 as api_dot_v1_dot_common__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import (
    annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x61pi/v1/customer.proto\x12\x06\x61pi.v1\x1a\x13\x61pi/v1/common.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto"<\n\x15\x43reateCustomerRequest\x12#\n\x05\x62uyer\x18\x01 \x01(\x0b\x32\r.api.v1.BuyerR\x05\x62uyer"N\n\x16\x43reateCustomerResponse\x12\x34\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x18.api.v1.MerchantCustomerR\x08\x63ustomer"0\n\x12GetCustomerRequest\x12\x1a\n\x08\x63ustomer\x18\x01 \x01(\tR\x08\x63ustomer"C\n\x13GetCustomerResponse\x12,\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x10.api.v1.CustomerR\x08\x63ustomer"\x83\x06\n\x15UpdateCustomerRequest\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer\x12U\n\x05\x65mail\x18\x02 \x01(\tB:\xbaH7\xba\x01\x34\n\x0bvalid_email\x12\x15must be a valid email\x1a\x0ethis.isEmail()H\x00R\x05\x65mail\x88\x01\x01\x12 \n\tforce_kyc\x18\x03 \x01(\x08H\x01R\x08\x66orceKyc\x88\x01\x01\x12"\n\x04name\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x02R\x04name\x88\x01\x01\x12<\n\x12katakana_last_name\x18\x0b \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x03R\x10katakanaLastName\x88\x01\x01\x12>\n\x13katakana_first_name\x18\x0c \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x04R\x11katakanaFirstName\x88\x01\x01\x12(\n\x07\x61\x64\x64ress\x18\r \x01(\tB\t\xbaH\x06r\x04\x10\x05\x18\x64H\x05R\x07\x61\x64\x64ress\x88\x01\x01\x12\x41\n\nbirth_date\x18\x14 \x01(\tB\x1d\xbaH\x1ar\x18\x32\x16^(\\d{4}-\\d{2}-\\d{2})?$H\x06R\tbirthDate\x88\x01\x01\x12\x39\n\x06gender\x18\x15 \x01(\tB\x1c\xbaH\x19r\x17R\x06\x66\x65maleR\x04maleR\x07unknownH\x07R\x06gender\x88\x01\x01\x12G\n\x08metadata\x18\x1e \x03(\x0b\x32+.api.v1.UpdateCustomerRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_emailB\x0c\n\n_force_kycB\x07\n\x05_nameB\x15\n\x13_katakana_last_nameB\x16\n\x14_katakana_first_nameB\n\n\x08_addressB\r\n\x0b_birth_dateB\t\n\x07_gender"N\n\x16UpdateCustomerResponse\x12\x34\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x18.api.v1.MerchantCustomerR\x08\x63ustomer"D\n\x15\x44\x65leteCustomerRequest\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer"4\n\x16\x44\x65leteCustomerResponse\x12\x1a\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08R\x08\x61\x63\x63\x65pted"A\n\x12GetContractRequest\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer"y\n\x13GetContractResponse\x12\x34\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x18.api.v1.MerchantCustomerR\x08\x63ustomer\x12,\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x10.api.v1.ContractR\x08\x63ontract2\xd4\x08\n\x0f\x43ustomerService\x12\xca\x01\n\x0e\x43reateCustomer\x12\x1d.api.v1.CreateCustomerRequest\x1a\x1e.api.v1.CreateCustomerResponse"y\x92\x41^\n\x08\x63ustomer\x12\x0f\x43reate customer\x1a\x39Intended for pre-registering merchant customer into Jamm.*\x06\x63reate\x82\xd3\xe4\x93\x02\x12"\r/v1/customers:\x01*\x12\xe4\x01\n\x0bGetCustomer\x12\x1a.api.v1.GetCustomerRequest\x1a\x1b.api.v1.GetCustomerResponse"\x9b\x01\x92\x41x\n\x08\x63ustomer\x12\x0cGet customer\x1aYRetrieve a merchant customer from Jamm. The merchant customer must be registered in Jamm.*\x03get\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/customers/{customer}\x12\xf7\x01\n\x0eUpdateCustomer\x12\x1d.api.v1.UpdateCustomerRequest\x1a\x1e.api.v1.UpdateCustomerResponse"\xa5\x01\x92\x41\x7f\n\x08\x63ustomer\x12\x0fUpdate customer\x1aZUpdate customer metadata when they updated their information in merchant e-commerce store.*\x06update\x82\xd3\xe4\x93\x02\x1d\x1a\x18/v1/customers/{customer}:\x01*\x12\xb3\x01\n\x0e\x44\x65leteCustomer\x12\x1d.api.v1.DeleteCustomerRequest\x1a\x1e.api.v1.DeleteCustomerResponse"b\x92\x41?\n\x08\x63ustomer\x12\x0f\x44\x65lete customer\x1a\x1a\x44\x65lete customer from Jamm.*\x06\x64\x65lete\x82\xd3\xe4\x93\x02\x1a*\x18/v1/customers/{customer}\x12\xdc\x01\n\x0bGetContract\x12\x1a.api.v1.GetContractRequest\x1a\x1b.api.v1.GetContractResponse"\x93\x01\x92\x41g\n\x08\x63ustomer\x12&Get a contract belongs to the customer\x1a&Get a contract belongs to the customer*\x0bgetContract\x82\xd3\xe4\x93\x02#\x12!/v1/customers/{customer}/contractBq\n\ncom.api.v1B\rCustomerProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.customer_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\rCustomerProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["customer"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["email"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "email"
    ]._serialized_options = b"\272H7\272\0014\n\013valid_email\022\025must be a valid email\032\016this.isEmail()"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["name"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_last_name"
    ]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_last_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_first_name"
    ]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_first_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["address"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "address"
    ]._serialized_options = b"\272H\006r\004\020\005\030d"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "birth_date"
    ]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "birth_date"
    ]._serialized_options = b"\272H\032r\0302\026^(\\d{4}-\\d{2}-\\d{2})?$"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["gender"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "gender"
    ]._serialized_options = b"\272H\031r\027R\006femaleR\004maleR\007unknown"
    _globals["_DELETECUSTOMERREQUEST"].fields_by_name["customer"]._loaded_options = None
    _globals["_DELETECUSTOMERREQUEST"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_GETCONTRACTREQUEST"].fields_by_name["customer"]._loaded_options = None
    _globals["_GETCONTRACTREQUEST"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "CreateCustomer"
    ]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "CreateCustomer"
    ]._serialized_options = b'\222A^\n\010customer\022\017Create customer\0329Intended for pre-registering merchant customer into Jamm.*\006create\202\323\344\223\002\022"\r/v1/customers:\001*'
    _globals["_CUSTOMERSERVICE"].methods_by_name["GetCustomer"]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "GetCustomer"
    ]._serialized_options = b"\222Ax\n\010customer\022\014Get customer\032YRetrieve a merchant customer from Jamm. The merchant customer must be registered in Jamm.*\003get\202\323\344\223\002\032\022\030/v1/customers/{customer}"
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "UpdateCustomer"
    ]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "UpdateCustomer"
    ]._serialized_options = b"\222A\177\n\010customer\022\017Update customer\032ZUpdate customer metadata when they updated their information in merchant e-commerce store.*\006update\202\323\344\223\002\035\032\030/v1/customers/{customer}:\001*"
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "DeleteCustomer"
    ]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "DeleteCustomer"
    ]._serialized_options = b"\222A?\n\010customer\022\017Delete customer\032\032Delete customer from Jamm.*\006delete\202\323\344\223\002\032*\030/v1/customers/{customer}"
    _globals["_CUSTOMERSERVICE"].methods_by_name["GetContract"]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "GetContract"
    ]._serialized_options = b"\222Ag\n\010customer\022&Get a contract belongs to the customer\032&Get a contract belongs to the customer*\013getContract\202\323\344\223\002#\022!/v1/customers/{customer}/contract"
    _globals["_CREATECUSTOMERREQUEST"]._serialized_start = 161
    _globals["_CREATECUSTOMERREQUEST"]._serialized_end = 221
    _globals["_CREATECUSTOMERRESPONSE"]._serialized_start = 223
    _globals["_CREATECUSTOMERRESPONSE"]._serialized_end = 301
    _globals["_GETCUSTOMERREQUEST"]._serialized_start = 303
    _globals["_GETCUSTOMERREQUEST"]._serialized_end = 351
    _globals["_GETCUSTOMERRESPONSE"]._serialized_start = 353
    _globals["_GETCUSTOMERRESPONSE"]._serialized_end = 420
    _globals["_UPDATECUSTOMERREQUEST"]._serialized_start = 423
    _globals["_UPDATECUSTOMERREQUEST"]._serialized_end = 1194
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._serialized_start = 1017
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._serialized_end = 1076
    _globals["_UPDATECUSTOMERRESPONSE"]._serialized_start = 1196
    _globals["_UPDATECUSTOMERRESPONSE"]._serialized_end = 1274
    _globals["_DELETECUSTOMERREQUEST"]._serialized_start = 1276
    _globals["_DELETECUSTOMERREQUEST"]._serialized_end = 1344
    _globals["_DELETECUSTOMERRESPONSE"]._serialized_start = 1346
    _globals["_DELETECUSTOMERRESPONSE"]._serialized_end = 1398
    _globals["_GETCONTRACTREQUEST"]._serialized_start = 1400
    _globals["_GETCONTRACTREQUEST"]._serialized_end = 1465
    _globals["_GETCONTRACTRESPONSE"]._serialized_start = 1467
    _globals["_GETCONTRACTRESPONSE"]._serialized_end = 1588
    _globals["_CUSTOMERSERVICE"]._serialized_start = 1591
    _globals["_CUSTOMERSERVICE"]._serialized_end = 2699
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import merchant_webhooks_pb2 as api_dot_v1_dot_merchant__webhooks__pb2


class WebhookServiceStub(object):
    """WebhookService is a placeholder service just to let OpenAPI codegen.
    Jamm's current OpenAPI generator only generates code that is associated
    with services.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Message = channel.unary_unary(
            "/api.v1.WebhookService/Message",
            request_serializer=api_dot_v1_dot_merchant__webhooks__pb2.MessageRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_merchant__webhooks__pb2.MessageResponse.FromString,
            _registered_method=True,
        )


class WebhookServiceServicer(object):
    """WebhookService is a placeholder service just to let OpenAPI codegen.
    Jamm's current OpenAPI generator only generates code that is associated
    with services.
    """

    def Message(self, request, context):
        """Message placeholder.
        This method is not implemented on Jamm backend.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WebhookServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Message": grpc.unary_unary_rpc_method_handler(
            servicer.Message,
            request_deserializer=api_dot_v1_dot_merchant__webhooks__pb2.MessageRequest.FromString,
            response_serializer=api_dot_v1_dot_merchant__webhooks__pb2.MessageResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v1.WebhookService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("api.v1.WebhookService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class WebhookService(object):
    """WebhookService is a placeholder service just to let OpenAPI codegen.
    Jamm's current OpenAPI generator only generates code that is associated
    with services.
    """

    @staticmethod
    def Message(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.WebhookService/Message",
            api_dot_v1_dot_merchant__webhooks__pb2.MessageRequest.SerializeToString,
            api_dot_v1_dot_merchant__webhooks__pb2.MessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



"""Customer models for Jamm SDK."""

from lib.proto.api.v1.customer_pb2 import (
    CreateCustomerRequest as _CreateCustomerRequest,
    CreateCustomerResponse as _CreateCustomerResponse,
    GetCustomerRequest as _GetCustomerRequest,
    GetCustomerResponse as _GetCustomerResponse,
    UpdateCustomerRequest as _UpdateCustomerRequest,
    UpdateCustomerResponse as _UpdateCustomerResponse,
    DeleteCustomerRequest as _DeleteCustomerRequest,
    DeleteCustomerResponse as _DeleteCustomerResponse,
    GetContractRequest as _GetContractRequest,
    GetContractResponse as _GetContractResponse,
)

# Direct re-exports
CreateCustomerRequest = _CreateCustomerRequest
CreateCustomerResponse = _CreateCustomerResponse
GetCustomerRequest = _GetCustomerRequest
GetCustomerResponse = _GetCustomerResponse
UpdateCustomerRequest = _UpdateCustomerRequest
UpdateCustomerResponse = _UpdateCustomerResponse
DeleteCustomerRequest = _DeleteCustomerRequest
DeleteCustomerResponse = _DeleteCustomerResponse
GetContractRequest = _GetContractRequest
GetContractResponse = _GetContractResponse



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ERROR_TYPE_UNSPECIFIED: _ClassVar[ErrorType]
    ERROR_TYPE_AUTH_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_AUTH_REJECTED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_CREATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_MODIFICATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_DELETION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_BANK_REGISTRATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_KYC_REJECTED: _ClassVar[ErrorType]
    ERROR_TYPE_NOTIFICATION_WEBHOOK_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_NOTIFICATION_EMAIL_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_NOTIFICATION_SMS_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_GATEWAY_UNAVAILABLE: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_GATEWAY_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_VALIDATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_REJECTED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_OVER_LIMIT: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_SUBSCRIPTION_EXPIRED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_LINK_EXPIRED: _ClassVar[ErrorType]

ERROR_TYPE_UNSPECIFIED: ErrorType
ERROR_TYPE_AUTH_FAILED: ErrorType
ERROR_TYPE_AUTH_REJECTED: ErrorType
ERROR_TYPE_ACCOUNT_CREATION_FAILED: ErrorType
ERROR_TYPE_ACCOUNT_MODIFICATION_FAILED: ErrorType
ERROR_TYPE_ACCOUNT_DELETION_FAILED: ErrorType
ERROR_TYPE_ACCOUNT_BANK_REGISTRATION_FAILED: ErrorType
ERROR_TYPE_KYC_REJECTED: ErrorType
ERROR_TYPE_NOTIFICATION_WEBHOOK_FAILED: ErrorType
ERROR_TYPE_NOTIFICATION_EMAIL_FAILED: ErrorType
ERROR_TYPE_NOTIFICATION_SMS_FAILED: ErrorType
ERROR_TYPE_PAYMENT_GATEWAY_UNAVAILABLE: ErrorType
ERROR_TYPE_PAYMENT_GATEWAY_FAILED: ErrorType
ERROR_TYPE_PAYMENT_VALIDATION_FAILED: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_FAILED: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_REJECTED: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_OVER_LIMIT: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_SUBSCRIPTION_EXPIRED: ErrorType
ERROR_TYPE_PAYMENT_LINK_EXPIRED: ErrorType



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNSPECIFIED: _ClassVar[EventType]
    EVENT_TYPE_CHARGE_CREATED: _ClassVar[EventType]
    EVENT_TYPE_CHARGE_UPDATED: _ClassVar[EventType]
    EVENT_TYPE_CHARGE_SUCCESS: _ClassVar[EventType]
    EVENT_TYPE_CHARGE_FAIL: _ClassVar[EventType]
    EVENT_TYPE_CHARGE_CANCEL: _ClassVar[EventType]
    EVENT_TYPE_CONTRACT_ACTIVATED: _ClassVar[EventType]
    EVENT_TYPE_USER_ACCOUNT_DELETED: _ClassVar[EventType]
    EVENT_TYPE_TESTING: _ClassVar[EventType]

EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_CHARGE_CREATED: EventType
EVENT_TYPE_CHARGE_UPDATED: EventType
EVENT_TYPE_CHARGE_SUCCESS: EventType
EVENT_TYPE_CHARGE_FAIL: EventType
EVENT_TYPE_CHARGE_CANCEL: EventType
EVENT_TYPE_CONTRACT_ACTIVATED: EventType
EVENT_TYPE_USER_ACCOUNT_DELETED: EventType
EVENT_TYPE_TESTING: EventType

class MessageRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MessageResponse(_message.Message):
    __slots__ = (
        "merchant_webhook_message",
        "charge_message",
        "contract_message",
        "user_account_message",
    )
    MERCHANT_WEBHOOK_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CHARGE_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    USER_ACCOUNT_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    merchant_webhook_message: MerchantWebhookMessage
    charge_message: ChargeMessage
    contract_message: ContractMessage
    user_account_message: UserAccountMessage
    def __init__(
        self,
        merchant_webhook_message: _Optional[
            _Union[MerchantWebhookMessage, _Mapping]
        ] = ...,
        charge_message: _Optional[_Union[ChargeMessage, _Mapping]] = ...,
        contract_message: _Optional[_Union[ContractMessage, _Mapping]] = ...,
        user_account_message: _Optional[_Union[UserAccountMessage, _Mapping]] = ...,
    ) -> None: ...

class MerchantWebhookMessage(_message.Message):
    __slots__ = ("id", "signature", "event_type", "content", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    signature: str
    event_type: EventType
    content: _any_pb2.Any
    created_at: _timestamp_pb2.Timestamp
    def __init__(
        self,
        id: _Optional[str] = ...,
        signature: _Optional[str] = ...,
        event_type: _Optional[_Union[EventType, str]] = ...,
        content: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class ChargeMessage(_message.Message):
    __slots__ = (
        "id",
        "customer",
        "status",
        "description",
        "merchant_name",
        "initial_amount",
        "discount",
        "final_amount",
        "amount_refunded",
        "currency",
        "processed_at",
        "created_at",
        "updated_at",
        "error",
    )

    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATUS_UNSPECIFIED: _ClassVar[ChargeMessage.Status]
        STATUS_SUCCESS: _ClassVar[ChargeMessage.Status]
        STATUS_FAILURE: _ClassVar[ChargeMessage.Status]
        STATUS_WAITING_EKYC: _ClassVar[ChargeMessage.Status]
        STATUS_BLOCKING: _ClassVar[ChargeMessage.Status]
        STATUS_CANCELLED: _ClassVar[ChargeMessage.Status]

    STATUS_UNSPECIFIED: ChargeMessage.Status
    STATUS_SUCCESS: ChargeMessage.Status
    STATUS_FAILURE: ChargeMessage.Status
    STATUS_WAITING_EKYC: ChargeMessage.Status
    STATUS_BLOCKING: ChargeMessage.Status
    STATUS_CANCELLED: ChargeMessage.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MERCHANT_NAME_FIELD_NUMBER: _ClassVar[int]
    INITIAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DISCOUNT_FIELD_NUMBER: _ClassVar[int]
    FINAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_REFUNDED_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    PROCESSED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer: str
    status: ChargeMessage.Status
    description: str
    merchant_name: str
    initial_amount: int
    discount: int
    final_amount: int
    amount_refunded: int
    currency: str
    processed_at: str
    created_at: str
    updated_at: str
    error: Error
    def __init__(
        self,
        id: _Optional[str] = ...,
        customer: _Optional[str] = ...,
        status: _Optional[_Union[ChargeMessage.Status, str]] = ...,
        description: _Optional[str] = ...,
        merchant_name: _Optional[str] = ...,
        initial_amount: _Optional[int] = ...,
        discount: _Optional[int] = ...,
        final_amount: _Optional[int] = ...,
        amount_refunded: _Optional[int] = ...,
        currency: _Optional[str] = ...,
        processed_at: _Optional[str] = ...,
        created_at: _Optional[str] = ...,
        updated_at: _Optional[str] = ...,
        error: _Optional[_Union[Error, _Mapping]] = ...,
    ) -> None: ...

class ContractMessage(_message.Message):
    __slots__ = ("customer", "created_at", "activated_at", "merchant_name")
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVATED_AT_FIELD_NUMBER: _ClassVar[int]
    MERCHANT_NAME_FIELD_NUMBER: _ClassVar[int]
    customer: str
    created_at: str
    activated_at: str
    merchant_name: str
    def __init__(
        self,
        customer: _Optional[str] = ...,
        created_at: _Optional[str] = ...,
        activated_at: _Optional[str] = ...,
        merchant_name: _Optional[str] = ...,
    ) -> None: ...

class UserAccountMessage(_message.Message):
    __slots__ = ("customer", "email", "deleted_at", "merchant_name")
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    MERCHANT_NAME_FIELD_NUMBER: _ClassVar[int]
    customer: str
    email: str
    deleted_at: str
    merchant_name: str
    def __init__(
        self,
        customer: _Optional[str] = ...,
        email: _Optional[str] = ...,
        deleted_at: _Optional[str] = ...,
        merchant_name: _Optional[str] = ...,
    ) -> None: ...

class Error(_message.Message):
    __slots__ = ("code", "message")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: str
    message: str
    def __init__(
        self, code: _Optional[str] = ..., message: _Optional[str] = ...
    ) -> None: ...



from typing import Dict, Any, Optional, Tuple
from .client import ApiClient


class HealthcheckApi:
    """Healthcheck API operations"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api_client = api_client or ApiClient()

    def ping(self, **kwargs) -> Dict[str, Any]:
        """Ping Jamm server to check connection"""
        data, status_code, headers = self.ping_with_http_info(**kwargs)
        return data

    def ping_with_http_info(self, **kwargs) -> Tuple[Any, int, Dict]:
        """Ping with full HTTP info"""
        opts = {"return_type": "object", "accepts": ["application/json"], **kwargs}
        return self.api_client.call_api("GET", "/v1/healthcheck", opts)



from api.v1 import common_pb2 as _common_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCustomerRequest(_message.Message):
    __slots__ = ("buyer",)
    BUYER_FIELD_NUMBER: _ClassVar[int]
    buyer: _common_pb2.Buyer
    def __init__(
        self, buyer: _Optional[_Union[_common_pb2.Buyer, _Mapping]] = ...
    ) -> None: ...

class CreateCustomerResponse(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: _common_pb2.MerchantCustomer
    def __init__(
        self, customer: _Optional[_Union[_common_pb2.MerchantCustomer, _Mapping]] = ...
    ) -> None: ...

class GetCustomerRequest(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: str
    def __init__(self, customer: _Optional[str] = ...) -> None: ...

class GetCustomerResponse(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: _common_pb2.Customer
    def __init__(
        self, customer: _Optional[_Union[_common_pb2.Customer, _Mapping]] = ...
    ) -> None: ...

class UpdateCustomerRequest(_message.Message):
    __slots__ = (
        "customer",
        "email",
        "force_kyc",
        "name",
        "katakana_last_name",
        "katakana_first_name",
        "address",
        "birth_date",
        "gender",
        "metadata",
    )

    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FORCE_KYC_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    KATAKANA_LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    KATAKANA_FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BIRTH_DATE_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    customer: str
    email: str
    force_kyc: bool
    name: str
    katakana_last_name: str
    katakana_first_name: str
    address: str
    birth_date: str
    gender: str
    metadata: _containers.ScalarMap[str, str]
    def __init__(
        self,
        customer: _Optional[str] = ...,
        email: _Optional[str] = ...,
        force_kyc: bool = ...,
        name: _Optional[str] = ...,
        katakana_last_name: _Optional[str] = ...,
        katakana_first_name: _Optional[str] = ...,
        address: _Optional[str] = ...,
        birth_date: _Optional[str] = ...,
        gender: _Optional[str] = ...,
        metadata: _Optional[_Mapping[str, str]] = ...,
    ) -> None: ...

class UpdateCustomerResponse(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: _common_pb2.MerchantCustomer
    def __init__(
        self, customer: _Optional[_Union[_common_pb2.MerchantCustomer, _Mapping]] = ...
    ) -> None: ...

class DeleteCustomerRequest(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: str
    def __init__(self, customer: _Optional[str] = ...) -> None: ...

class DeleteCustomerResponse(_message.Message):
    __slots__ = ("accepted",)
    ACCEPTED_FIELD_NUMBER: _ClassVar[int]
    accepted: bool
    def __init__(self, accepted: bool = ...) -> None: ...

class GetContractRequest(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: str
    def __init__(self, customer: _Optional[str] = ...) -> None: ...

class GetContractResponse(_message.Message):
    __slots__ = ("customer", "contract")
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    customer: _common_pb2.MerchantCustomer
    contract: _common_pb2.Contract
    def __init__(
        self,
        customer: _Optional[_Union[_common_pb2.MerchantCustomer, _Mapping]] = ...,
        contract: _Optional[_Union[_common_pb2.Contract, _Mapping]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v1/webapp.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "common/v1/webapp.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x63ommon/v1/webapp.proto\x12\tcommon.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x9d\x06\n\x04\x42\x61nk\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x03 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x04 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x05 \x01(\tR\x0cnameAlphabet\x12-\n\x06\x61ssets\x18\x0b \x01(\x0b\x32\x15.common.v1.BankAssetsR\x06\x61ssets\x12*\n\x05quota\x18\x14 \x01(\x0b\x32\x14.common.v1.BankQuotaR\x05quota\x12#\n\ropening_hours\x18\x1e \x01(\tR\x0copeningHours\x12o\n\x1e\x62\x61nkpay_scheduled_maintenances\x18( \x03(\x0b\x32).common.v1.BankScheduledMaintenancePeriodR\x1c\x62\x61nkpayScheduledMaintenances\x12i\n\x1b\x62\x61nk_scheduled_maintenances\x18) \x03(\x0b\x32).common.v1.BankScheduledMaintenancePeriodR\x19\x62\x61nkScheduledMaintenances\x12y\n#registration_scheduled_maintenances\x18* \x03(\x0b\x32).common.v1.BankScheduledMaintenancePeriodR!registrationScheduledMaintenances\x12+\n\x11\x62\x61nkpay_available\x18\x32 \x01(\x08R\x10\x62\x61nkpayAvailable\x12%\n\x0e\x62\x61nk_available\x18\x33 \x01(\x08R\rbankAvailable\x12\x35\n\x16registration_available\x18\x34 \x01(\x08R\x15registrationAvailable\x12\x1c\n\toperating\x18\x63 \x01(\x08R\toperating"\x83\x06\n\tBankQuota\x12X\n*offline_purchase_limit_per_charge_with_kyc\x18\x01 \x01(\x05R$offlinePurchaseLimitPerChargeWithKyc\x12^\n-offline_purchase_limit_per_charge_without_kyc\x18\x02 \x01(\x05R\'offlinePurchaseLimitPerChargeWithoutKyc\x12R\n\'offline_purchase_limit_per_day_with_kyc\x18\n \x01(\x05R!offlinePurchaseLimitPerDayWithKyc\x12X\n*offline_purchase_limit_per_day_without_kyc\x18\x0b \x01(\x05R$offlinePurchaseLimitPerDayWithoutKyc\x12\x62\n/subscription_purchase_limit_per_charge_with_kyc\x18\x14 \x01(\x05R)subscriptionPurchaseLimitPerChargeWithKyc\x12h\n2subscription_purchase_limit_per_charge_without_kyc\x18\x15 \x01(\x05R,subscriptionPurchaseLimitPerChargeWithoutKyc\x12\\\n,subscription_purchase_limit_per_day_with_kyc\x18\x1e \x01(\x05R&subscriptionPurchaseLimitPerDayWithKyc\x12\x62\n/subscription_purchase_limit_per_day_without_kyc\x18\x1f \x01(\x05R)subscriptionPurchaseLimitPerDayWithoutKyc"\xbd\x01\n\x1e\x42\x61nkScheduledMaintenancePeriod\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12 \n\x0cstart_at_jst\x18\x02 \x01(\tR\nstartAtJst\x12\x1c\n\nend_at_jst\x18\x03 \x01(\tR\x08\x65ndAtJst\x12 \n\x0cstart_at_utc\x18\x04 \x01(\tR\nstartAtUtc\x12\x1c\n\nend_at_utc\x18\x05 \x01(\tR\x08\x65ndAtUtc"\xcd\x01\n\nBankBranch\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12\x1f\n\x0b\x62ranch_code\x18\x02 \x01(\tR\nbranchCode\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x04 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x05 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x06 \x01(\tR\x0cnameAlphabet"\x94\x01\n\nBankAssets\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12$\n\x0elogo_url_large\x18\x02 \x01(\tR\x0clogoUrlLarge\x12&\n\x0flogo_url_medium\x18\x03 \x01(\tR\rlogoUrlMedium\x12\x1b\n\tterms_url\x18\n \x01(\tR\x08termsUrl"\x97\x05\n\x05\x42uyer\x12P\n\x05\x65mail\x18\x01 \x01(\tB:\xbaH7\xba\x01\x34\n\x0bvalid_email\x12\x15must be a valid email\x1a\x0ethis.isEmail()R\x05\x65mail\x12\x1b\n\tforce_kyc\x18\x02 \x01(\x08R\x08\x66orceKyc\x12"\n\x04name\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x00R\x04name\x88\x01\x01\x12<\n\x12katakana_last_name\x18\x0b \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x01R\x10katakanaLastName\x88\x01\x01\x12>\n\x13katakana_first_name\x18\x0c \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x02R\x11katakanaFirstName\x88\x01\x01\x12(\n\x07\x61\x64\x64ress\x18\r \x01(\tB\t\xbaH\x06r\x04\x10\x05\x18\x64H\x03R\x07\x61\x64\x64ress\x88\x01\x01\x12\x41\n\nbirth_date\x18\x14 \x01(\tB\x1d\xbaH\x1ar\x18\x32\x16^(\\d{4}-\\d{2}-\\d{2})?$H\x04R\tbirthDate\x88\x01\x01\x12\x39\n\x06gender\x18\x15 \x01(\tB\x1c\xbaH\x19r\x17R\x06\x66\x65maleR\x04maleR\x07unknownH\x05R\x06gender\x88\x01\x01\x12:\n\x08metadata\x18\x1e \x03(\x0b\x32\x1e.common.v1.Buyer.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x15\n\x13_katakana_last_nameB\x16\n\x14_katakana_first_nameB\n\n\x08_addressB\r\n\x0b_birth_dateB\t\n\x07_gender"{\n\x03Kyc\x12\x1b\n\tpublic_id\x18\x01 \x01(\tR\x08publicId\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x13.common.v1.KycStateR\x05state\x12,\n\x06result\x18\x03 \x01(\x0e\x32\x14.common.v1.KycResultR\x06result"\x81\x01\n\nDateFilter\x12,\n\x05range\x18\x01 \x01(\x0b\x32\x14.common.v1.DateRangeH\x00R\x05range\x12;\n\nexact_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\texactDateB\x08\n\x06\x66ilter"}\n\tDateRange\x12\x39\n\nstart_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartDate\x12\x35\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndDate"^\n\x0eUserAgreements\x12L\n\x13jamm_user_agreement\x18\x02 \x01(\x0b\x32\x1c.common.v1.JammUserAgreementR\x11jammUserAgreement"\xb6\x01\n\x11JammUserAgreement\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12G\n\x0e\x61greement_name\x18\x02 \x01(\x0e\x32 .common.v1.JammUserAgreementNameR\ragreementName\x12\x37\n\tagreed_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x61greedAt"\xe6\x03\n\rTrustdockData\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n\tpublic_id\x18\x02 \x01(\tR\x08publicId\x12\x14\n\x05state\x18\x03 \x01(\tR\x05state\x12\x16\n\x06result\x18\x04 \x01(\tR\x06result\x12;\n\x0b\x61\x63\x63\x65pted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nacceptedAt\x12\x46\n\x11plans_selected_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0fplansSelectedAt\x12N\n\x15\x64ocument_submitted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13\x64ocumentSubmittedAt\x12;\n\x0bprepared_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\npreparedAt\x12;\n\x0bverified_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAt\x12+\n\x07records\x18\n \x03(\x0b\x32\x11.common.v1.RecordR\x07records"\x8d\x01\n\x06Record\x12\x14\n\x05state\x18\x01 \x01(\tR\x05state\x12\x16\n\x06result\x18\x02 \x01(\tR\x06result\x12\x18\n\x07\x63ontent\x18\x03 \x01(\tR\x07\x63ontent\x12;\n\x0bverified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAt*X\n\x06Gender\x12\x16\n\x12GENDER_UNSPECIFIED\x10\x00\x12\x11\n\rGENDER_FEMALE\x10\x01\x12\x0f\n\x0bGENDER_MALE\x10\x02\x12\x12\n\x0eGENDER_UNKNOWN\x10\x03*\xa0\x01\n\x0c\x43ommonStatus\x12\x1d\n\x19\x43OMMON_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43OMMON_STATUS_INITIAL\x10\x01\x12\x1b\n\x17\x43OMMON_STATUS_ACTIVATED\x10\x02\x12\x1d\n\x19\x43OMMON_STATUS_DEACTIVATED\x10\x03\x12\x1a\n\x16\x43OMMON_STATUS_BLOCKING\x10\x04*\xd8\x01\n\x0c\x43hargeStatus\x12\x1d\n\x19\x43HARGE_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43HARGE_STATUS_SUCCESS\x10\x01\x12\x19\n\x15\x43HARGE_STATUS_FAILURE\x10\x02\x12\x1e\n\x1a\x43HARGE_STATUS_WAITING_EKYC\x10\x03\x12\x1a\n\x16\x43HARGE_STATUS_BLOCKING\x10\x04\x12\x1b\n\x17\x43HARGE_STATUS_CANCELLED\x10\x05\x12\x1a\n\x16\x43HARGE_STATUS_REFUNDED\x10\x06*\x9d\x01\n\x15JammUserAgreementName\x12(\n$JAMM_USER_AGREEMENT_NAME_UNSPECIFIED\x10\x00\x12+\n\'JAMM_USER_AGREEMENT_NAME_PRIVACY_POLICY\x10\x01\x12-\n)JAMM_USER_AGREEMENT_NAME_TERMS_OF_SERVICE\x10\x02*\xe1\x01\n\x08KycState\x12\x19\n\x15KYC_STATE_UNSPECIFIED\x10\x00\x12\x16\n\x12KYC_STATE_ACCEPTED\x10\x01\x12\x1c\n\x18KYC_STATE_PLANS_SELECTED\x10\x02\x12 \n\x1cKYC_STATE_DOCUMENT_SUBMITTED\x10\x03\x12\x19\n\x15KYC_STATE_IN_PROGRESS\x10\x04\x12\x16\n\x12KYC_STATE_VERIFIED\x10\x05\x12\x19\n\x15KYC_STATE_NOT_STARTED\x10\x06\x12\x14\n\x10KYC_STATE_DENIED\x10\x07*W\n\tKycResult\x12\x1a\n\x16KYC_RESULT_UNSPECIFIED\x10\x00\x12\x17\n\x13KYC_RESULT_APPROVED\x10\x01\x12\x15\n\x11KYC_RESULT_DENIED\x10\x02*\xb4\x01\n\x0cRefundStatus\x12\x1d\n\x19REFUND_STATUS_UNSPECIFIED\x10\x00\x12&\n"REFUND_STATUS_WAITING_CONFIRMATION\x10\x01\x12\x1b\n\x17REFUND_STATUS_CONFIRMED\x10\x02\x12\x18\n\x14REFUND_STATUS_FAILED\x10\x03\x12&\n"REFUND_STATUS_CANCELED_BY_MERCHANT\x10\x04*\xb1\x01\n\x0cRejectReason\x12\x1d\n\x19REJECT_REASON_UNSPECIFIED\x10\x00\x12)\n%REJECT_REASON_MERCHANT_REQUEST_DENIED\x10\x01\x12+\n\'REJECT_REASON_NEGATIVE_MERCHANT_BALANCE\x10\x02\x12*\n&REJECT_REASON_PAYMENT_REJECTED_BY_BANK\x10\x03\x42\x84\x01\n\rcom.common.v1B\x0bWebappProtoP\x01Z!api/proto/gen/common/v1;common_v1\xa2\x02\x03\x43XX\xaa\x02\tCommon.V1\xca\x02\tCommon\\V1\xe2\x02\x15\x43ommon\\V1\\GPBMetadata\xea\x02\nCommon::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common.v1.webapp_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\rcom.common.v1B\013WebappProtoP\001Z!api/proto/gen/common/v1;common_v1\242\002\003CXX\252\002\tCommon.V1\312\002\tCommon\\V1\342\002\025Common\\V1\\GPBMetadata\352\002\nCommon::V1"
    )
    _globals["_BUYER_METADATAENTRY"]._loaded_options = None
    _globals["_BUYER_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_BUYER"].fields_by_name["email"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "email"
    ]._serialized_options = b"\272H7\272\0014\n\013valid_email\022\025must be a valid email\032\016this.isEmail()"
    _globals["_BUYER"].fields_by_name["name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_last_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_last_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_first_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_first_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["address"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "address"
    ]._serialized_options = b"\272H\006r\004\020\005\030d"
    _globals["_BUYER"].fields_by_name["birth_date"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "birth_date"
    ]._serialized_options = b"\272H\032r\0302\026^(\\d{4}-\\d{2}-\\d{2})?$"
    _globals["_BUYER"].fields_by_name["gender"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "gender"
    ]._serialized_options = b"\272H\031r\027R\006femaleR\004maleR\007unknown"
    _globals["_GENDER"]._serialized_start = 4188
    _globals["_GENDER"]._serialized_end = 4276
    _globals["_COMMONSTATUS"]._serialized_start = 4279
    _globals["_COMMONSTATUS"]._serialized_end = 4439
    _globals["_CHARGESTATUS"]._serialized_start = 4442
    _globals["_CHARGESTATUS"]._serialized_end = 4658
    _globals["_JAMMUSERAGREEMENTNAME"]._serialized_start = 4661
    _globals["_JAMMUSERAGREEMENTNAME"]._serialized_end = 4818
    _globals["_KYCSTATE"]._serialized_start = 4821
    _globals["_KYCSTATE"]._serialized_end = 5046
    _globals["_KYCRESULT"]._serialized_start = 5048
    _globals["_KYCRESULT"]._serialized_end = 5135
    _globals["_REFUNDSTATUS"]._serialized_start = 5138
    _globals["_REFUNDSTATUS"]._serialized_end = 5318
    _globals["_REJECTREASON"]._serialized_start = 5321
    _globals["_REJECTREASON"]._serialized_end = 5498
    _globals["_BANK"]._serialized_start = 100
    _globals["_BANK"]._serialized_end = 897
    _globals["_BANKQUOTA"]._serialized_start = 900
    _globals["_BANKQUOTA"]._serialized_end = 1671
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_start = 1674
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_end = 1863
    _globals["_BANKBRANCH"]._serialized_start = 1866
    _globals["_BANKBRANCH"]._serialized_end = 2071
    _globals["_BANKASSETS"]._serialized_start = 2074
    _globals["_BANKASSETS"]._serialized_end = 2222
    _globals["_BUYER"]._serialized_start = 2225
    _globals["_BUYER"]._serialized_end = 2888
    _globals["_BUYER_METADATAENTRY"]._serialized_start = 2735
    _globals["_BUYER_METADATAENTRY"]._serialized_end = 2794
    _globals["_KYC"]._serialized_start = 2890
    _globals["_KYC"]._serialized_end = 3013
    _globals["_DATEFILTER"]._serialized_start = 3016
    _globals["_DATEFILTER"]._serialized_end = 3145
    _globals["_DATERANGE"]._serialized_start = 3147
    _globals["_DATERANGE"]._serialized_end = 3272
    _globals["_USERAGREEMENTS"]._serialized_start = 3274
    _globals["_USERAGREEMENTS"]._serialized_end = 3368
    _globals["_JAMMUSERAGREEMENT"]._serialized_start = 3371
    _globals["_JAMMUSERAGREEMENT"]._serialized_end = 3553
    _globals["_TRUSTDOCKDATA"]._serialized_start = 3556
    _globals["_TRUSTDOCKDATA"]._serialized_end = 4042
    _globals["_RECORD"]._serialized_start = 4045
    _globals["_RECORD"]._serialized_end = 4186
# @@protoc_insertion_point(module_scope)



"""Jamm SDK Models - Public API."""

# Payment models
from .payment import (
    # Enhanced models
    Charge,
    # Direct proto exports
    URL,
    InitialCharge,
    PaymentLink,
    ChargeResult,
    AddChargeRequest,
    AddChargeResponse,
    CreateContractWithChargeRequest,
    CreateContractWithChargeResponse,
    CreateContractWithoutChargeRequest,
    CreateContractWithoutChargeResponse,
    GetChargeRequest,
    GetChargeResponse,
    GetChargesRequest,
    GetChargesResponse,
    OffSessionPaymentRequest,
    OffSessionPaymentResponse,
    WithdrawRequest,
    WithdrawResponse,
    OnSessionPaymentRequest,
    OnSessionPaymentResponse,
    OnSessionPaymentData,
    OnSessionPaymentError,
    OnSessionPaymentErrorCode,
)

# Banking models
from .banking import (
    Bank,
    BankQuota,
    BankBranch,
    BankAssets,
    GetBankRequest,
    GetBankResponse,
    GetMajorBanksRequest,
    GetMajorBanksResponse,
    SearchBanksRequest,
    SearchBanksResponse,
    GetBranchRequest,
    GetBranchResponse,
    GetBranchesRequest,
    GetBranchesResponse,
    SearchBranchesRequest,
    SearchBranchesResponse,
)

# Common models
from .common import (
    # Enhanced models
    Buyer,
    # Direct proto exports
    Customer,
    MerchantCustomer,
    Contract,
    Pagination,
    Status,
    BankInformation,
    Merchant,
    DepositType,
    PaymentAuthorizationStatus,
    KycStatus,
    ContractStatus,
)

# Customer models
from .customer import (
    CreateCustomerRequest,
    CreateCustomerResponse,
    GetCustomerRequest,
    GetCustomerResponse,
    UpdateCustomerRequest,
    UpdateCustomerResponse,
    DeleteCustomerRequest,
    DeleteCustomerResponse,
    GetContractRequest,
    GetContractResponse,
)

# Healthcheck models
from .healthcheck import (
    PingRequest,
    PingResponse,
)

# Define public API
__all__ = [
    # Payment
    "Charge",
    "URL",
    "InitialCharge",
    "PaymentLink",
    "ChargeResult",
    "AddChargeRequest",
    "AddChargeResponse",
    "CreateContractWithChargeRequest",
    "CreateContractWithChargeResponse",
    "CreateContractWithoutChargeRequest",
    "CreateContractWithoutChargeResponse",
    "GetChargeRequest",
    "GetChargeResponse",
    "GetChargesRequest",
    "GetChargesResponse",
    "OffSessionPaymentRequest",
    "OffSessionPaymentResponse",
    "WithdrawRequest",
    "WithdrawResponse",
    "OnSessionPaymentRequest",
    "OnSessionPaymentResponse",
    "OnSessionPaymentData",
    "OnSessionPaymentError",
    "OnSessionPaymentErrorCode",
    # Banking
    "Bank",
    "BankQuota",
    "Branch",
    "BankAssets",
    "GetBankRequest",
    "GetBankResponse",
    "GetMajorBanksRequest",
    "GetMajorBanksResponse",
    "SearchBanksRequest",
    "SearchBanksResponse",
    "GetBranchRequest",
    "GetBranchResponse",
    "GetBranchesRequest",
    "GetBranchesResponse",
    "SearchBranchesRequest",
    "SearchBranchesResponse",
    # Common
    "Buyer",
    "Customer",
    "MerchantCustomer",
    "Contract",
    "Pagination",
    "Status",
    "BankInformation",
    "Merchant",
    "DepositType",
    "PaymentAuthorizationStatus",
    "KycStatus",
    "ContractStatus",
    # Customer
    "CreateCustomerRequest",
    "CreateCustomerResponse",
    "GetCustomerRequest",
    "GetCustomerResponse",
    "UpdateCustomerRequest",
    "UpdateCustomerResponse",
    "DeleteCustomerRequest",
    "DeleteCustomerResponse",
    "GetContractRequest",
    "GetContractResponse",
    # Healthcheck
    "PingRequest",
    "PingResponse",
]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import payment_pb2 as api_dot_v1_dot_payment__pb2


class PaymentServiceStub(object):
    """# Payment Service

    This service provides functionality for managing contracts and charges.
    It allows for creating contracts both with and without initial charges,
    as well as adding charges to existing contracts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateContractWithoutCharge = channel.unary_unary(
            "/api.v1.PaymentService/CreateContractWithoutCharge",
            request_serializer=api_dot_v1_dot_payment__pb2.CreateContractWithoutChargeRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.CreateContractWithoutChargeResponse.FromString,
            _registered_method=True,
        )
        self.CreateContractWithCharge = channel.unary_unary(
            "/api.v1.PaymentService/CreateContractWithCharge",
            request_serializer=api_dot_v1_dot_payment__pb2.CreateContractWithChargeRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.CreateContractWithChargeResponse.FromString,
            _registered_method=True,
        )
        self.AddCharge = channel.unary_unary(
            "/api.v1.PaymentService/AddCharge",
            request_serializer=api_dot_v1_dot_payment__pb2.AddChargeRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.AddChargeResponse.FromString,
            _registered_method=True,
        )
        self.GetCharge = channel.unary_unary(
            "/api.v1.PaymentService/GetCharge",
            request_serializer=api_dot_v1_dot_payment__pb2.GetChargeRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.GetChargeResponse.FromString,
            _registered_method=True,
        )
        self.GetCharges = channel.unary_unary(
            "/api.v1.PaymentService/GetCharges",
            request_serializer=api_dot_v1_dot_payment__pb2.GetChargesRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.GetChargesResponse.FromString,
            _registered_method=True,
        )
        self.Withdraw = channel.unary_unary(
            "/api.v1.PaymentService/Withdraw",
            request_serializer=api_dot_v1_dot_payment__pb2.WithdrawRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.WithdrawResponse.FromString,
            _registered_method=True,
        )
        self.OffSessionPayment = channel.unary_unary(
            "/api.v1.PaymentService/OffSessionPayment",
            request_serializer=api_dot_v1_dot_payment__pb2.OffSessionPaymentRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.OffSessionPaymentResponse.FromString,
            _registered_method=True,
        )
        self.OnSessionPayment = channel.unary_unary(
            "/api.v1.PaymentService/OnSessionPayment",
            request_serializer=api_dot_v1_dot_payment__pb2.OnSessionPaymentRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_payment__pb2.OnSessionPaymentResponse.FromString,
            _registered_method=True,
        )


class PaymentServiceServicer(object):
    """# Payment Service

    This service provides functionality for managing contracts and charges.
    It allows for creating contracts both with and without initial charges,
    as well as adding charges to existing contracts.
    """

    def CreateContractWithoutCharge(self, request, context):
        """## CreateContractWithoutCharge

        Creates a new contract without an initial charge. This is useful when you want to
        establish a billing relationship with a customer but don't need to charge them immediately.

        The contract can later be used with AddCharge to apply charges as needed.

        **Parameters:**
        - CreateContractWithoutChargeRequest: Contains buyer information and redirect details

        **Returns:**
        - CreateContractWithoutChargeResponse: Contains the created payment link with contract ID, merchant customer ID

        **Service function reference:**
        ```go
        func (s *paymentService) CreateContractWithoutCharge(ctx context.Context, req *CreateContractWithoutChargeRequest) (*CreateContractWithoutChargeResponse, error) {
        // Validates buyer information
        // Creates contract ID in payment info database
        // Create merchant customer if not exists
        // Creates payment link
        // Returns payment link with contract ID and merchant customer ID
        }
        ```
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateContractWithCharge(self, request, context):
        """## CreateContractWithCharge

        Creates a new contract with an immediate initial charge. This combines
        contract creation and charging in a single operation for convenience.

        This is typically used for initial sign-ups that require immediate payment.

        **Parameters:**
        - CreateContractWithChargeRequest: Contains buyer information, redirect details, and charge information

        **Returns:**
        - CreateContractWithChargeResponse: Contains the created payment link with contract ID, charge ID, merchant customer ID

        **Service function reference:**
        ```go
        func (s *paymentService) CreateContractWithCharge(ctx context.Context, req *CreateContractWithChargeRequest) (*CreateContractWithChargeResponse, error) {
        // Validates buyer and payment information
        // Creates contract ID and charge ID in payment info database
        // Create merchant customer if not exists
        // Creates payment link
        // Returns payment link with contract and charge IDs along with merchant customer ID
        }
        ```
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddCharge(self, request, context):
        """## AddCharge

        Adds a new charge to an existing contract. This allows for charging
        a jamm user after a contract has been established.

        Common uses include recurring billing, add-on purchases, or usage-based charges.

        **Parameters:**
        - AddChargeRequest: Contains merchant customer ID and charge details

        **Returns:**
        - AddChargeResponse: Contains the created payment link with charge ID

        **Service function reference:**
        ```go
        func (s *paymentService) AddCharge(ctx context.Context, req *AddChargeRequest) (*AddChargeResponse, error) {
        // Validates contract links to the merchant customer and payment information
        // Creates charge ID in payment info database
        // Creates payment link
        // Returns payment link with contract and charge IDs
        }
        ```
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCharge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCharges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Withdraw(self, request, context):
        """Withdraw

        Withdraws money from a customer immediately. This call is synchronous.

        @param WithdrawRequest Contains merchant customer ID and charge details
        @return WithdrawResponse Contains the created payment link with charge ID

        Service function reference:
        func (s *paymentService) Withdraw(ctx context.Context, req *WithdrawRequest) (*WithdrawResponse, error) {
        // Validates contract links to the merchant customer and payment information
        // Creates charge ID in payment info database
        // Creates payment link
        // Returns payment link with contract and charge IDs
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OffSessionPayment(self, request, context):
        """## OffSessionPayment

        Processes a payment directly within your application without requiring redirects.
        This is an off-session payment that executes immediately and synchronously.

        This API is used for existing customers - Executes a charge to an existing customer when a customer ID is provided

        @param OffSessionPaymentRequest: Contains optional customer ID and charge details
        @return OffSessionPaymentResponse: Contains the charge result and customer information

        **Service function reference:**
        ```go
        func (s *paymentService) Withdraw(ctx context.Context, req *WithdrawRequest) (*WithdrawResponse, error) {
        // Validates payment information
        // Processes the payment immediately without redirects
        // Returns charge result and customer information
        }
        ```
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OnSessionPayment(self, request, context):
        """## OnSessionPayment

        Provides a unified interface for creating payment sessions. This API intelligently routes
        requests to the appropriate method based on the provided parameters:

        - When a customer ID is provided: Uses AddCharge for existing customers
        - When buyer + charge are provided: Uses CreateContractWithCharge for new customers with charges
        - When only buyer is provided: Uses CreateContractWithoutCharge for new customers without charges

        **Parameters:**
        - OnSessionPaymentRequest: Contains optional customer/buyer info, optional charge details, and redirect URLs

        **Returns:**
        - OnSessionPaymentResponse: Contains unified payment information including payment link

        **Service function reference:**
        ```go
        func (s *paymentService) OnSessionPayment(ctx context.Context, req *OnSessionPaymentRequest) (*OnSessionPaymentResponse, error) {
        // Determines appropriate payment strategy based on request parameters
        // Routes to AddCharge, CreateContractWithCharge, or CreateContractWithoutCharge
        // Returns standardized response with payment link and relevant details
        }
        ```
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PaymentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateContractWithoutCharge": grpc.unary_unary_rpc_method_handler(
            servicer.CreateContractWithoutCharge,
            request_deserializer=api_dot_v1_dot_payment__pb2.CreateContractWithoutChargeRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.CreateContractWithoutChargeResponse.SerializeToString,
        ),
        "CreateContractWithCharge": grpc.unary_unary_rpc_method_handler(
            servicer.CreateContractWithCharge,
            request_deserializer=api_dot_v1_dot_payment__pb2.CreateContractWithChargeRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.CreateContractWithChargeResponse.SerializeToString,
        ),
        "AddCharge": grpc.unary_unary_rpc_method_handler(
            servicer.AddCharge,
            request_deserializer=api_dot_v1_dot_payment__pb2.AddChargeRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.AddChargeResponse.SerializeToString,
        ),
        "GetCharge": grpc.unary_unary_rpc_method_handler(
            servicer.GetCharge,
            request_deserializer=api_dot_v1_dot_payment__pb2.GetChargeRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.GetChargeResponse.SerializeToString,
        ),
        "GetCharges": grpc.unary_unary_rpc_method_handler(
            servicer.GetCharges,
            request_deserializer=api_dot_v1_dot_payment__pb2.GetChargesRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.GetChargesResponse.SerializeToString,
        ),
        "Withdraw": grpc.unary_unary_rpc_method_handler(
            servicer.Withdraw,
            request_deserializer=api_dot_v1_dot_payment__pb2.WithdrawRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.WithdrawResponse.SerializeToString,
        ),
        "OffSessionPayment": grpc.unary_unary_rpc_method_handler(
            servicer.OffSessionPayment,
            request_deserializer=api_dot_v1_dot_payment__pb2.OffSessionPaymentRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.OffSessionPaymentResponse.SerializeToString,
        ),
        "OnSessionPayment": grpc.unary_unary_rpc_method_handler(
            servicer.OnSessionPayment,
            request_deserializer=api_dot_v1_dot_payment__pb2.OnSessionPaymentRequest.FromString,
            response_serializer=api_dot_v1_dot_payment__pb2.OnSessionPaymentResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v1.PaymentService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("api.v1.PaymentService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class PaymentService(object):
    """# Payment Service

    This service provides functionality for managing contracts and charges.
    It allows for creating contracts both with and without initial charges,
    as well as adding charges to existing contracts.
    """

    @staticmethod
    def CreateContractWithoutCharge(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/CreateContractWithoutCharge",
            api_dot_v1_dot_payment__pb2.CreateContractWithoutChargeRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.CreateContractWithoutChargeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def CreateContractWithCharge(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/CreateContractWithCharge",
            api_dot_v1_dot_payment__pb2.CreateContractWithChargeRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.CreateContractWithChargeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def AddCharge(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/AddCharge",
            api_dot_v1_dot_payment__pb2.AddChargeRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.AddChargeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetCharge(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/GetCharge",
            api_dot_v1_dot_payment__pb2.GetChargeRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.GetChargeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetCharges(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/GetCharges",
            api_dot_v1_dot_payment__pb2.GetChargesRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.GetChargesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Withdraw(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/Withdraw",
            api_dot_v1_dot_payment__pb2.WithdrawRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.WithdrawResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def OffSessionPayment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/OffSessionPayment",
            api_dot_v1_dot_payment__pb2.OffSessionPaymentRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.OffSessionPaymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def OnSessionPayment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.PaymentService/OnSessionPayment",
            api_dot_v1_dot_payment__pb2.OnSessionPaymentRequest.SerializeToString,
            api_dot_v1_dot_payment__pb2.OnSessionPaymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: error/v1/error.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "error/v1/error.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x65rror/v1/error.proto\x12\x08\x65rror.v1*\x83\x06\n\tErrorType\x12\x1a\n\x16\x45RROR_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45RROR_TYPE_AUTH_FAILED\x10\x01\x12\x1c\n\x18\x45RROR_TYPE_AUTH_REJECTED\x10\x02\x12&\n"ERROR_TYPE_ACCOUNT_CREATION_FAILED\x10\x65\x12*\n&ERROR_TYPE_ACCOUNT_MODIFICATION_FAILED\x10\x66\x12&\n"ERROR_TYPE_ACCOUNT_DELETION_FAILED\x10g\x12/\n+ERROR_TYPE_ACCOUNT_BANK_REGISTRATION_FAILED\x10h\x12\x1c\n\x17\x45RROR_TYPE_KYC_REJECTED\x10\xad\x02\x12+\n&ERROR_TYPE_NOTIFICATION_WEBHOOK_FAILED\x10\xf4\x03\x12)\n$ERROR_TYPE_NOTIFICATION_EMAIL_FAILED\x10\xf5\x03\x12\'\n"ERROR_TYPE_NOTIFICATION_SMS_FAILED\x10\xf6\x03\x12+\n&ERROR_TYPE_PAYMENT_GATEWAY_UNAVAILABLE\x10\xe8\x07\x12&\n!ERROR_TYPE_PAYMENT_GATEWAY_FAILED\x10\xe9\x07\x12)\n$ERROR_TYPE_PAYMENT_VALIDATION_FAILED\x10\xea\x07\x12%\n ERROR_TYPE_PAYMENT_CHARGE_FAILED\x10\xeb\x07\x12\'\n"ERROR_TYPE_PAYMENT_CHARGE_REJECTED\x10\xec\x07\x12)\n$ERROR_TYPE_PAYMENT_CHARGE_OVER_LIMIT\x10\xed\x07\x12\x33\n.ERROR_TYPE_PAYMENT_CHARGE_SUBSCRIPTION_EXPIRED\x10\xee\x07\x12$\n\x1f\x45RROR_TYPE_PAYMENT_LINK_EXPIRED\x10\xef\x07\x42\x80\x01\n\x0c\x63om.error.v1B\nErrorProtoP\x01Z!error/proto/gen/error/v1;error_v1\xa2\x02\x03\x45XX\xaa\x02\x08\x45rror.V1\xca\x02\tError_\\V1\xe2\x02\x15\x45rror_\\V1\\GPBMetadata\xea\x02\tError::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "error.v1.error_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\014com.error.v1B\nErrorProtoP\001Z!error/proto/gen/error/v1;error_v1\242\002\003EXX\252\002\010Error.V1\312\002\tError_\\V1\342\002\025Error_\\V1\\GPBMetadata\352\002\tError::V1"
    )
    _globals["_ERRORTYPE"]._serialized_start = 35
    _globals["_ERRORTYPE"]._serialized_end = 806
# @@protoc_insertion_point(module_scope)



from typing import Dict, Any, List, Optional
from .api.payment_api import PaymentApi
from .api.client import ApiClient
from .errors import ApiError


class Charge:
    """High-level charge operations"""

    def __init__(self, api_client: Optional[ApiClient] = None):
        self.api = PaymentApi(api_client)

    def create_without_redirect(
        self,
        customer_id: str,
        price: int,
        description: Optional[str] = None,
        currency: str = "JPY",
        **kwargs
    ) -> Dict[str, Any]:
        """
        Create a charge without redirect URLs

        Args:
            customer_id: Customer ID
            price: Charge amount
            description: Charge description
            currency: Currency code (default: JPY)
            **kwargs: Additional parameters

        Returns:
            Created charge data

        Raises:
            ApiError: If charge creation fails
        """
        try:
            # Create charge object
            charge = {"price": price, "currency": currency}

            if description:
                charge["description"] = description

            # Add any additional kwargs to charge object
            for key, value in kwargs.items():
                if key not in ["customer"]:
                    charge[key] = value

            # Build request body
            request_body = {"customer": customer_id, "charge": charge}

            return self.api.withdraw(request_body)
        except Exception as e:
            raise ApiError.from_error(e)

    def create_with_redirect(
        self,
        customer_id: str,
        price: int,
        success_url: str,
        failure_url: str,
        description: Optional[str] = None,
        currency: str = "JPY",
        expires_at: Optional[str] = None,
        **kwargs
    ) -> Dict[str, Any]:
        """
        Create a charge with redirect URLs for hosted checkout

        Args:
            customer_id: Customer ID
            price: Charge amount
            success_url: URL to redirect after successful payment
            failure_url: URL to redirect after failed payment
            description: Charge description
            currency: Currency code (default: JPY)
            expires_at: ISO-8601 format expiration date
            **kwargs: Additional parameters

        Returns:
            Created charge data with payment URL

        Raises:
            ApiError: If charge creation fails
        """
        try:
            # Create charge object
            charge = {"price": price, "currency": currency}

            if description:
                charge["description"] = description

            if expires_at:
                charge["expires_at"] = expires_at

            # Build request body
            request_body = {
                "customer": customer_id,
                "charge": charge,
                "redirect": {"success_url": success_url, "failure_url": failure_url},
            }

            # Add any remaining kwargs
            for key, value in kwargs.items():
                if key not in ["customer", "charge", "redirect"]:
                    request_body[key] = value

            return self.api.add_charge(request_body)
        except Exception as e:
            raise ApiError.from_error(e)

    def get(self, charge_id: str) -> Dict[str, Any]:
        """
        Get a specific charge

        Args:
            charge_id: Charge ID

        Returns:
            Charge data

        Raises:
            ApiError: If charge retrieval fails or charge not found
        """
        try:
            return self.api.get_charge(charge_id)
        except Exception as e:
            raise ApiError.from_error(e)

    def list(
        self,
        customer_id: str,
        page_size: Optional[int] = None,
        page_token: Optional[str] = None,
    ) -> Dict[str, Any]:
        """
        List charges for a customer

        Args:
            customer_id: Customer ID
            page_size: Number of charges per page
            page_token: Pagination token

        Returns:
            List of charges with pagination info

        Raises:
            ApiError: If charge listing fails
        """
        try:
            return self.api.get_charges(customer_id, page_size, page_token)
        except Exception as e:
            raise ApiError.from_error(e)

    def _get_auth_headers(self):
        """Debug method to check what authorization headers are being used"""
        if (
            hasattr(self.api, "api_client")
            and self.api.api_client
            and hasattr(self.api.api_client, "config")
        ):
            config = self.api.api_client.config
            if hasattr(config, "auth_settings") and "oauth2" in config.auth_settings:
                auth_setting = config.auth_settings["oauth2"]
                if callable(auth_setting.get("value")):
                    header_value = auth_setting["value"]()
                    return {auth_setting["key"]: header_value}
        return None



import sys
import importlib
from importlib.abc import MetaPathFinder
from importlib.machinery import ModuleSpec


class ApiImportHook(MetaPathFinder):
    """Import hook that redirects proto imports"""

    def __init__(self):
        self.redirects = {
            "api": "lib.proto.api",
            "common": "lib.proto.common",
            "error": "lib.proto.error",
            "buf": "lib.proto.buf",
        }
        self.processing = set()

    def find_spec(self, fullname, path=None, target=None):
        if fullname in self.processing:
            return None

        prefix = fullname.split(".")[0]
        if prefix in self.redirects:
            self.processing.add(fullname)
            try:
                redirected = fullname.replace(prefix, self.redirects[prefix], 1)
                try:
                    module = importlib.import_module(redirected)
                    sys.modules[fullname] = module
                    return importlib.util.find_spec(redirected)
                except ImportError:
                    pass
            finally:
                self.processing.remove(fullname)
        return None


def install():
    if not any(isinstance(finder, ApiImportHook) for finder in sys.meta_path):
        sys.meta_path.insert(0, ApiImportHook())
        print("API import hook installed")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/common.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/common.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x61pi/v1/common.proto\x12\x06\x61pi.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb6\x06\n\x05\x42uyer\x12P\n\x05\x65mail\x18\x01 \x01(\tB:\xbaH7\xba\x01\x34\n\x0bvalid_email\x12\x15must be a valid email\x1a\x0ethis.isEmail()R\x05\x65mail\x12\x1b\n\tforce_kyc\x18\x02 \x01(\x08R\x08\x66orceKyc\x12\x36\n\x05phone\x18\x03 \x01(\tB\x1b\xbaH\x18r\x16\x32\x11^0[789]0[0-9]{8}$\x98\x01\x0bH\x00R\x05phone\x88\x01\x01\x12"\n\x04name\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x01R\x04name\x88\x01\x01\x12<\n\x12katakana_last_name\x18\x0b \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x02R\x10katakanaLastName\x88\x01\x01\x12>\n\x13katakana_first_name\x18\x0c \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x03R\x11katakanaFirstName\x88\x01\x01\x12(\n\x07\x61\x64\x64ress\x18\r \x01(\tB\t\xbaH\x06r\x04\x10\x05\x18\x64H\x04R\x07\x61\x64\x64ress\x88\x01\x01\x12\x41\n\nbirth_date\x18\x14 \x01(\tB\x1d\xbaH\x1ar\x18\x32\x16^(\\d{4}-\\d{2}-\\d{2})?$H\x05R\tbirthDate\x88\x01\x01\x12\x39\n\x06gender\x18\x15 \x01(\tB\x1c\xbaH\x19r\x17R\x06\x66\x65maleR\x04maleR\x07unknownH\x06R\x06gender\x88\x01\x01\x12O\n\nexpires_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xbaH\x0c\xb2\x01\t@\x00J\x05\x08\x80\x9a\x9e\x01H\x07R\texpiresAt\x88\x01\x01\x12\x37\n\x08metadata\x18\x1e \x03(\x0b\x32\x1b.api.v1.Buyer.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_phoneB\x07\n\x05_nameB\x15\n\x13_katakana_last_nameB\x16\n\x14_katakana_first_nameB\n\n\x08_addressB\r\n\x0b_birth_dateB\t\n\x07_genderB\r\n\x0b_expires_at"n\n\x10MerchantCustomer\x12,\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x10.api.v1.CustomerR\x08\x63ustomer\x12,\n\x08merchant\x18\x02 \x01(\x0b\x32\x10.api.v1.MerchantR\x08merchant"\xc1\x02\n\x08\x43ustomer\x12\x1f\n\x02id\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x1c\n\tactivated\x18\x04 \x01(\x08R\tactivated\x12&\n\x06status\x18\x05 \x01(\x0b\x32\x0e.api.v1.StatusR\x06status\x12\x42\n\x10\x62\x61nk_information\x18\x06 \x01(\x0b\x32\x17.api.v1.BankInformationR\x0f\x62\x61nkInformation\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt"k\n\x06Status\x12<\n\x07payment\x18\x01 \x01(\x0e\x32".api.v1.PaymentAuthorizationStatusR\x07payment\x12#\n\x03kyc\x18\x02 \x01(\x0e\x32\x11.api.v1.KycStatusR\x03kyc"\xae\x01\n\x0f\x42\x61nkInformation\x12%\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tR\raccountNumber\x12\x1b\n\tbank_name\x18\x02 \x01(\tR\x08\x62\x61nkName\x12\x1f\n\x0b\x62ranch_name\x18\x03 \x01(\tR\nbranchName\x12\x36\n\x0c\x64\x65posit_type\x18\x04 \x01(\x0e\x32\x13.api.v1.DepositTypeR\x0b\x64\x65positType"?\n\x08Merchant\x12\x1f\n\x02id\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^mer-.*$R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name"\xd2\x01\n\x08\x43ontract\x12 \n\x02id\x18\x01 \x01(\tB\x10\xbaH\rr\x0b\x32\t^con-\\d+$R\x02id\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x16.api.v1.ContractStatusR\x06status\x12\x39\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt"S\n\nPagination\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64 \x00R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken"\x8e\x06\n\x04\x42\x61nk\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x03 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x04 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x05 \x01(\tR\x0cnameAlphabet\x12*\n\x06\x61ssets\x18\x0b \x01(\x0b\x32\x12.api.v1.BankAssetsR\x06\x61ssets\x12\'\n\x05quota\x18\x14 \x01(\x0b\x32\x11.api.v1.BankQuotaR\x05quota\x12#\n\ropening_hours\x18\x1e \x01(\tR\x0copeningHours\x12l\n\x1e\x62\x61nkpay_scheduled_maintenances\x18( \x03(\x0b\x32&.api.v1.BankScheduledMaintenancePeriodR\x1c\x62\x61nkpayScheduledMaintenances\x12\x66\n\x1b\x62\x61nk_scheduled_maintenances\x18) \x03(\x0b\x32&.api.v1.BankScheduledMaintenancePeriodR\x19\x62\x61nkScheduledMaintenances\x12v\n#registration_scheduled_maintenances\x18* \x03(\x0b\x32&.api.v1.BankScheduledMaintenancePeriodR!registrationScheduledMaintenances\x12+\n\x11\x62\x61nkpay_available\x18\x32 \x01(\x08R\x10\x62\x61nkpayAvailable\x12%\n\x0e\x62\x61nk_available\x18\x33 \x01(\x08R\rbankAvailable\x12\x35\n\x16registration_available\x18\x34 \x01(\x08R\x15registrationAvailable\x12\x1c\n\toperating\x18\x63 \x01(\x08R\toperating"\x83\x06\n\tBankQuota\x12X\n*offline_purchase_limit_per_charge_with_kyc\x18\x01 \x01(\x05R$offlinePurchaseLimitPerChargeWithKyc\x12^\n-offline_purchase_limit_per_charge_without_kyc\x18\x02 \x01(\x05R\'offlinePurchaseLimitPerChargeWithoutKyc\x12R\n\'offline_purchase_limit_per_day_with_kyc\x18\n \x01(\x05R!offlinePurchaseLimitPerDayWithKyc\x12X\n*offline_purchase_limit_per_day_without_kyc\x18\x0b \x01(\x05R$offlinePurchaseLimitPerDayWithoutKyc\x12\x62\n/subscription_purchase_limit_per_charge_with_kyc\x18\x14 \x01(\x05R)subscriptionPurchaseLimitPerChargeWithKyc\x12h\n2subscription_purchase_limit_per_charge_without_kyc\x18\x15 \x01(\x05R,subscriptionPurchaseLimitPerChargeWithoutKyc\x12\\\n,subscription_purchase_limit_per_day_with_kyc\x18\x1e \x01(\x05R&subscriptionPurchaseLimitPerDayWithKyc\x12\x62\n/subscription_purchase_limit_per_day_without_kyc\x18\x1f \x01(\x05R)subscriptionPurchaseLimitPerDayWithoutKyc"\xbd\x01\n\x1e\x42\x61nkScheduledMaintenancePeriod\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12 \n\x0cstart_at_jst\x18\x02 \x01(\tR\nstartAtJst\x12\x1c\n\nend_at_jst\x18\x03 \x01(\tR\x08\x65ndAtJst\x12 \n\x0cstart_at_utc\x18\x04 \x01(\tR\nstartAtUtc\x12\x1c\n\nend_at_utc\x18\x05 \x01(\tR\x08\x65ndAtUtc"\xcd\x01\n\nBankBranch\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12\x1f\n\x0b\x62ranch_code\x18\x02 \x01(\tR\nbranchCode\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x04 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x05 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x06 \x01(\tR\x0cnameAlphabet"\x94\x01\n\nBankAssets\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12$\n\x0elogo_url_large\x18\x02 \x01(\tR\x0clogoUrlLarge\x12&\n\x0flogo_url_medium\x18\x03 \x01(\tR\rlogoUrlMedium\x12\x1b\n\tterms_url\x18\n \x01(\tR\x08termsUrl*`\n\x0b\x44\x65positType\x12\x1c\n\x18\x44\x45POSIT_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x44\x45POSIT_TYPE_SAVINGS\x10\x01\x12\x19\n\x15\x44\x45POSIT_TYPE_CHECKING\x10\x02*\xa8\x01\n\x1aPaymentAuthorizationStatus\x12,\n(PAYMENT_AUTHORIZATION_STATUS_UNSPECIFIED\x10\x00\x12+\n\'PAYMENT_AUTHORIZATION_STATUS_AUTHORIZED\x10\x01\x12/\n+PAYMENT_AUTHORIZATION_STATUS_NOT_AUTHORIZED\x10\x02*\x8f\x01\n\tKycStatus\x12\x1a\n\x16KYC_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13KYC_STATUS_APPROVED\x10\x01\x12\x1c\n\x18KYC_STATUS_NOT_SUBMITTED\x10\x02\x12\x18\n\x14KYC_STATUS_IN_REVIEW\x10\x03\x12\x15\n\x11KYC_STATUS_DENIED\x10\x04*\xae\x02\n\x0e\x43ontractStatus\x12\x1f\n\x1b\x43ONTRACT_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONTRACT_STATUS_INITIAL\x10\x01\x12\x1c\n\x18\x43ONTRACT_STATUS_APPROVED\x10\x02\x12\x1d\n\x19\x43ONTRACT_STATUS_ACTIVATED\x10\x03\x12 \n\x1c\x43ONTRACT_STATUS_WAITING_EKYC\x10\x04\x12\x1b\n\x17\x43ONTRACT_STATUS_EXPIRED\x10\x05\x12\x1f\n\x1b\x43ONTRACT_STATUS_DEACTIVATED\x10\x06\x12\x1d\n\x19\x43ONTRACT_STATUS_CANCELLED\x10\x07\x12"\n\x1e\x43ONTRACT_STATUS_PENDING_CHARGE\x10\x08\x42o\n\ncom.api.v1B\x0b\x43ommonProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.common_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\013CommonProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_BUYER_METADATAENTRY"]._loaded_options = None
    _globals["_BUYER_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_BUYER"].fields_by_name["email"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "email"
    ]._serialized_options = b"\272H7\272\0014\n\013valid_email\022\025must be a valid email\032\016this.isEmail()"
    _globals["_BUYER"].fields_by_name["phone"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "phone"
    ]._serialized_options = b"\272H\030r\0262\021^0[789]0[0-9]{8}$\230\001\013"
    _globals["_BUYER"].fields_by_name["name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_last_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_last_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_first_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_first_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["address"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "address"
    ]._serialized_options = b"\272H\006r\004\020\005\030d"
    _globals["_BUYER"].fields_by_name["birth_date"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "birth_date"
    ]._serialized_options = b"\272H\032r\0302\026^(\\d{4}-\\d{2}-\\d{2})?$"
    _globals["_BUYER"].fields_by_name["gender"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "gender"
    ]._serialized_options = b"\272H\031r\027R\006femaleR\004maleR\007unknown"
    _globals["_BUYER"].fields_by_name["expires_at"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "expires_at"
    ]._serialized_options = b"\272H\014\262\001\t@\000J\005\010\200\232\236\001"
    _globals["_CUSTOMER"].fields_by_name["id"]._loaded_options = None
    _globals["_CUSTOMER"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_MERCHANT"].fields_by_name["id"]._loaded_options = None
    _globals["_MERCHANT"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\014r\n2\010^mer-.*$"
    _globals["_CONTRACT"].fields_by_name["id"]._loaded_options = None
    _globals["_CONTRACT"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\rr\0132\t^con-\\d+$"
    _globals["_PAGINATION"].fields_by_name["page_size"]._loaded_options = None
    _globals["_PAGINATION"].fields_by_name[
        "page_size"
    ]._serialized_options = b"\272H\006\032\004\030d \000"
    _globals["_DEPOSITTYPE"]._serialized_start = 4113
    _globals["_DEPOSITTYPE"]._serialized_end = 4209
    _globals["_PAYMENTAUTHORIZATIONSTATUS"]._serialized_start = 4212
    _globals["_PAYMENTAUTHORIZATIONSTATUS"]._serialized_end = 4380
    _globals["_KYCSTATUS"]._serialized_start = 4383
    _globals["_KYCSTATUS"]._serialized_end = 4526
    _globals["_CONTRACTSTATUS"]._serialized_start = 4529
    _globals["_CONTRACTSTATUS"]._serialized_end = 4831
    _globals["_BUYER"]._serialized_start = 94
    _globals["_BUYER"]._serialized_end = 916
    _globals["_BUYER_METADATAENTRY"]._serialized_start = 738
    _globals["_BUYER_METADATAENTRY"]._serialized_end = 797
    _globals["_MERCHANTCUSTOMER"]._serialized_start = 918
    _globals["_MERCHANTCUSTOMER"]._serialized_end = 1028
    _globals["_CUSTOMER"]._serialized_start = 1031
    _globals["_CUSTOMER"]._serialized_end = 1352
    _globals["_STATUS"]._serialized_start = 1354
    _globals["_STATUS"]._serialized_end = 1461
    _globals["_BANKINFORMATION"]._serialized_start = 1464
    _globals["_BANKINFORMATION"]._serialized_end = 1638
    _globals["_MERCHANT"]._serialized_start = 1640
    _globals["_MERCHANT"]._serialized_end = 1703
    _globals["_CONTRACT"]._serialized_start = 1706
    _globals["_CONTRACT"]._serialized_end = 1916
    _globals["_PAGINATION"]._serialized_start = 1918
    _globals["_PAGINATION"]._serialized_end = 2001
    _globals["_BANK"]._serialized_start = 2004
    _globals["_BANK"]._serialized_end = 2786
    _globals["_BANKQUOTA"]._serialized_start = 2789
    _globals["_BANKQUOTA"]._serialized_end = 3560
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_start = 3563
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_end = 3752
    _globals["_BANKBRANCH"]._serialized_start = 3755
    _globals["_BANKBRANCH"]._serialized_end = 3960
    _globals["_BANKASSETS"]._serialized_start = 3963
    _globals["_BANKASSETS"]._serialized_end = 4111
# @@protoc_insertion_point(module_scope)
